summaryrefslogtreecommitdiffstats
path: root/kjsembed/jssecuritypolicy.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/jssecuritypolicy.h')
-rw-r--r--kjsembed/jssecuritypolicy.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kjsembed/jssecuritypolicy.h b/kjsembed/jssecuritypolicy.h
index 0709b214..26e55881 100644
--- a/kjsembed/jssecuritypolicy.h
+++ b/kjsembed/jssecuritypolicy.h
@@ -36,7 +36,7 @@ class JSObjectProxy;
* A SecurityPolicy must define tests for the following situations:
* <ul>
* <li>Does this request come from the correct @ref KJS::Interpreter ?
* <li>Is the script allowed to access the specified QObject ?
* <li>Is the script allowed to access the specified property ?
* </ul>
* The various isAllowed() methods are called automatically by @ref JSObjectProxy
@@ -107,20 +107,20 @@ public:
virtual bool isInterpreterAllowed( const JSObjectProxy *prx, const KJS::Interpreter *interp ) const;
/**
* Returns true if scripts are allowed to see the specified QObject.
*/
- virtual bool isObjectAllowed( const JSObjectProxy *prx, const QObject *obj ) const;
+ virtual bool isObjectAllowed( const JSObjectProxy *prx, const TQObject *obj ) const;
/**
* Returns true if scripts are allowed to see the specified property.
*/
- virtual bool isPropertyAllowed( const JSObjectProxy *prx, const QObject *obj, const char *prop ) const;
+ virtual bool isPropertyAllowed( const JSObjectProxy *prx, const TQObject *obj, const char *prop ) const;
/**
* Returns true if scripts are allowed to create the specified child object.
*/
- virtual bool isCreateAllowed( const JSObjectProxy *prx, const QObject *parent,
- const QString &clazz, const QString &name ) const;
+ virtual bool isCreateAllowed( const JSObjectProxy *prx, const TQObject *parent,
+ const TQString &clazz, const TQString &name ) const;
/**
* Returns the default SecurityPolicy.
@@ -36,7 +36,7 @@ class JSObjectProxy;
* <ul>
* <li>Does this request come from the correct @ref KJS::Interpreter ?
- * <li>Is the script allowed to access the specified QObject ?
+ * <li>Is the script allowed to access the specified TQObject ?
* <li>Is the script allowed to access the specified property ?
* </ul>
@@ -107,20 +107,20 @@ public:
virtual bool isInterpreterAllowed( const JSObjectProxy *prx, const KJS::Interpreter *interp ) const;
/**
- * Returns true if scripts are allowed to see the specified QObject.
+ * Returns true if scripts are allowed to see the specified TQObject.
*/